@@ -66,8 +66,8 @@ class StyleguideLoaderTest(unittest.TestCase):
 
     def test__get_components_from_folder(self):
         expected_result = [
-            { 'id': u'footer', 'file_name': u'footer.html', 'name': u'footer', 'template': u'styleguide/layout/footer.html', 'doc': {}, 'link': STYLEGUIDE_URL+'layout/footer' },
-            { 'id': u'header', 'file_name': u'header.html', 'name': u'header', 'template': u'styleguide/layout/header.html', 'doc': {}, 'link': STYLEGUIDE_URL+'layout/header' }
+            { 'id': u'footer', 'file_name': u'footer.html', 'name': u'footer', 'template': u'styleguide/layout/footer.html', 'doc': {}, 'link': STYLEGUIDE_URL+'layout#footer' },
+            { 'id': u'header', 'file_name': u'header.html', 'name': u'header', 'template': u'styleguide/layout/header.html', 'doc': {}, 'link': STYLEGUIDE_URL+'layout#header' }
         ]
 
         path_to_test = os.path.join(MOCK_PROJECT_PATH, STYLEGUIDE_DIR_NAME)
@@ -131,3 +131,27 @@ class StyleguideTest(unittest.TestCase):
         expected_result = ['footer', 'header']
         result = [c.name for c in self.styleguide.modules[1].components]
         self.assertEqual(result, expected_result)
+
+
+    def test_set_current_module(self):
+        # Begins None
+        self.assertEqual(self.styleguide.current_module, None)
+        # Begins an empty list
+        self.assertEqual(self.styleguide.current_components, [])
+        # And we are in the index page
+        self.assertEqual(self.styleguide.is_index(), True)
+
+        expected_result = self.styleguide.modules[0]
+        self.styleguide.set_current_module('layout')
+        self.assertEqual(self.styleguide.current_module, expected_result)
+
+        # current_components
+        expected_result = self.styleguide.modules[0].components
+        self.assertEqual(self.styleguide.current_components, expected_result)
+
+        # Not index page anymore
+        self.assertEqual(self.styleguide.is_index(), False)
+
+
+
+
