@@ -12,6 +12,7 @@ from django.template.defaulttags import CommentNode
 
 
 STYLEGUIDE_DEBUG = getattr(settings, 'STYLEGUIDE_DEBUG', settings.DEBUG)
+STYLEGUIDE_CACHE_NAME = getattr(settings, 'STYLEGUIDE_CACHE_NAME', 'styleguide_components')
 STYLEGUIDE_DIR_NAME = getattr(settings, 'STYLEGUIDE_DIR_NAME', 'styleguide')
 STYLEGUIDE_IGNORE_FOLDERS = getattr(settings, 'STYLEGUIDE_IGNORE_FOLDERS', ('includes', ))
 
@@ -24,8 +25,10 @@ class Styleguide(object):
     def __init__(self):
         self._modules = None
         self._items = None
+        self.current_module = None
         self._loader = StyleguideLoader()
 
+
     @property
     def modules(self):
         if self._modules is None:
@@ -53,10 +56,35 @@ class Styleguide(object):
 
     @property
     def items(self):
-        """ For retro compatibility """
+        """
+        :deprecated: 
+        For retro compatibility only
+        """
         return self._loader.get_styleguide_components().items()
 
 
+    @property
+    def current_components(self):
+        if self.current_module is None:
+            return []
+        else:
+            return self.current_module.components
+
+
+    def set_current_module(self, module_name):
+        """ Sets the given module as the current one """
+        for module in self.modules:
+            if module.name == module_name:
+                self.current_module = module
+                break
+
+
+    def is_index(self):
+        """ If a module is defined as current, 
+        we say that we are not in an index page """
+        return self.current_module is None
+
+
 class StyleguideComponent(dict):
 
     def __init__(self, data):
